% This is a template for a dual-head set up
% It was used during A13.5 in 2010
% Modify it accordingly to your cruise

% cruise ID and name of person who processes the data %%%%%%%%%%%

p.cruise_id = 'A13_5_2010';
p.whoami = 'F. Ascani';

% root
root = '/home/science/';

% specify the cast number for stations that have several available casts
% (the present script can guess the cast number only if there is only one cast recorded)
CAST(72) = 1;
CAST(79) = 1;
CAST(82) = 1;

% command line to process SADCP data into a format that LDEO software can use
% because the access to the original SADCP data has changed during the cruise,
% different command lines are used depending on the station numbers
% Stations 1-29
source1='/home/science/current_cruise/data/RB1002leg2_reproc/os75nb/contour';
mkSADCP(source1,'/home/science/current_cruise/proc/ladcp_ldeo/data/ldeo_reprocessed_sadcp/ldeo_reprocessed_sadcp_leg2.mat')
% Stations 30-91
source2='/home/science/current_cruise/data/RB1002leg2a/proc/os75nb/contour';
mkSADCP(source2,'/home/science/current_cruise/proc/ladcp_ldeo/data/ldeo_reprocessed_sadcp/ldeo_reprocessed_sadcp_leg2a.mat')
% Stations 92-...
source2='/home/science/current_cruise/data/shipboard_adcp/proc/os75nb/contour';
mkSADCP(source2,'/home/science/current_cruise/proc/ladcp_ldeo/data/ldeo_reprocessed_sadcp/ldeo_reprocessed_sadcp_leg2b.mat')

% station number %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
p.ladcp_station = stn;

% filename of the raw LADCP data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ladcp_datapath = [root p.cruise_id '/data/ladcp/']
ladcp_filename_start_up = 'up';
ladcp_filename_start_dn = 'dn';
ladcp_filename_end = '.dat';
cast_loc_index = [7 8];
stn_str = sprintf('%03d',stn);

[w,ladcp_list_up]=unix(['ls ' ladcp_datapath ladcp_filename_start_up stn_str '*' ladcp_filename_end '*']);

if w ~= 0
  error('error while reading the LADCP up-looker data...')
end

% cases where there are several casts available
switch stn
   case 79
    if CAST(stn) == 1
     ladcp_list_up = ladcp_list_up(1:49); % first cast is taken
    elseif CAST(stn) == 2
     ladcp_list_up = ladcp_list_up(50:end); % second cast is taken
    end
   case 82
    if CAST(stn) == 1
     ladcp_list_up = ladcp_list_up(1:49); % first cast is taken
    elseif CAST(stn) == 2
     ladcp_list_up = ladcp_list_up(50:end); % second cast is taken
    end    
end

ladcp_filename_up = ladcp_list_up(1:end-1);
if ladcp_filename_up(1) ~= '/', ladcp_filename_up = ladcp_filename_up(2:end);end
cast_str = ladcp_filename_up(length(ladcp_datapath)+cast_loc_index);
cast_str_ctd = cast_str;

if stn>=120
   cast_str_ctd = cast_str(2);
end

f.ladcpup = sprintf(ladcp_filename_up);

if stn == 12

  f.ladcpdo = sprintf(ladcp_filename_up);
  f.ladcpup = '';

else

  [w,ladcp_list_dn]=unix(['ls ' ladcp_datapath ladcp_filename_start_dn stn_str '*' ladcp_filename_end '*']);

  if w ~= 0
     error('error while reading the LADCP down-looker data...')
  end

% cases where there are several casts available
switch stn
   case 79
    if CAST(stn) == 1
     ladcp_list_dn = ladcp_list_dn(1:49); % first cast is taken
    elseif CAST(stn) == 2
     ladcp_list_dn = ladcp_list_dn(50:end); % second cast is taken
    end
   case 82
    if CAST(stn) == 1
     ladcp_list_dn = ladcp_list_dn(1:49); % first cast is taken
    elseif CAST(stn) == 2
     ladcp_list_dn = ladcp_list_dn(50:end); % second cast is taken
    end    
end

   ladcp_filename_dn = ladcp_list_dn(1:end-1);
   if ladcp_filename_dn(1) ~= '/';ladcp_filename_dn = ladcp_filename_dn(2:end);end
   
   f.ladcpdo = sprintf(ladcp_filename_dn);

end
   
% CTD time series %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ctd_data = 'y';

if ctd_data == 'y'

% Scripps CTD data are now available
ctd_datapath = [root p.cruise_id '/data/ctd_timeseries/a13.5/'];
ctd_filename_start = '';
ctd_filename_end = '.ctd';

if stn>=120
   ctd_datapath = [root p.cruise_id '/data/ctd_timeseries/'];
   ctd_filename_start = 'formatted_rh1';
   ctd_filename_end = '.asc';
end

ctd_filename=[ctd_datapath ctd_filename_start stn_str cast_str_ctd ctd_filename_end]

f.ctd = sprintf(ctd_filename);

% number of header lines (before the CTD data start) %%%%%%%%%%%%
f.ctd_header_lines = 0; % file layout

% number of data fields per CTD scan %%%%%%%%%%%%%%%%%%%%%%%%%%%%
f.ctd_fields_per_line = 11;
if stn>=120
   f.ctd_fields_per_line = 10;
end

% field number for pressure, temperature, salinity and time %%%%%

f.ctd_pressure_field = 2;
f.ctd_temperature_field = 3;
f.ctd_salinity_field = 4;
f.ctd_time_field = 1;

if stn>=120
   f.ctd_pressure_field = 2;
   f.ctd_temperature_field = 3;
   f.ctd_salinity_field = 9;
   f.ctd_time_field = 1;
end

% time base to use %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 0=elapsed, 1=year-day, 2=gregorian
f.ctd_time_base = 0;

if stn>=120
   f.ctd_time_base = 1;
end

end

% GPS data? %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
gps_data = 'y';

if gps_data == 'y'

% GPS filename %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
f.nav = f.ctd; % if GPS and CTD data are in the same file

if stn>=120
   gps_datapath = [root p.cruise_id '/data/gps/'];
   gps_filename_start = 'rb2010_';
   gps_filename_end = '.asc';

   gps_filename = [gps_datapath gps_filename_start stn_str cast_str_ctd gps_filename_end]

   f.nav = sprintf(gps_filename); % otherwise
end

% number of header lines (before the GPS data start) %%%%%%%%%%%%
f.nav_header_lines = 0;
 
% number of fields per scan %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
f.nav_fields_per_line = 11;

if stn>=120
   f.nav_fields_per_line = 3;
end

% field number for time, latitude and longitude %%%%%%%%%%%%%%%%%

f.nav_time_field = 1;
f.nav_lat_field = 10;
f.nav_lon_field = 11;

if stn>=120
   f.nav_time_field = 1;
   f.nav_lat_field = 3;
   f.nav_lon_field = 2;
end

% time base to use %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 0=elapsed (default), 1=year-day, 2=gregorian
% 0 only if GPS and CTD data are co-recorded

f.nav_time_base = 0;

if stn>=120
   f.nav_time_base = 1;
end

end

% SADCP data? %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%sadcp_data_from_UH=input('SADCP data?\n','s'); % 'y'=yes, 'n'=no

sadcp_data_from_UH='y';

if sadcp_data_from_UH == 'y'

% SADCP MATLAB file %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if stn <= 29

   f.sadcp = 'data/ldeo_reprocessed_sadcp/ldeo_reprocessed_sadcp_leg2.mat';

elseif and(stn>=30,stn<=91)

   f.sadcp = 'data/ldeo_reprocessed_sadcp/ldeo_reprocessed_sadcp_leg2a.mat';

else

   f.sadcp = 'data/ldeo_reprocessed_sadcp/ldeo_reprocessed_sadcp_leg2b.mat';

end

p.sadcp_dtok = 0

%mkSADCP('/Data/ADCP/LADDER-1','../data/SADCP/SADCP.mat');
% every time to update the file when processing is down during the cruise
% one time after the cruise for post-processing

end

% CTD profile? %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ctdprof = 'n';

if ctdprof == 'y'

ctdprof_datapath = [root p.cruise_id '/data/ctd_2db/'];
ctdprof_filename_start = '';
ctdprof_filename_end = '.ctd';

ctdprof_filename=[ctdprof_datapath stn_str cast_str ctdprof_filename_end];

f.ctdprof = sprintf(ctdprof_filename);

end

% magnetic deviation %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if gps_data == 'n' % only if there is no GPS data; if there is,
                   % the magnetic devation will be set using geomag60

p.drot = magdev(latvec(stn+1),lonvec(stn+1)) % magnetic deviation

%or

%  p.poss =  0; % start position
%  p.pose =  0; %   end position

end

% save matlab files? %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

p.savemat = 1; % yes=1, no=0 (default)

% save figures? %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% p.saveplot_png = []; % yes=nothing, no=1 (default)

more off
clear pk

% basename of the checkpoint files %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
f.checkpoints = sprintf('checkpoints/%03d',stn);

% basename of the output files %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
f.res = sprintf('processed/%03d',stn);

% plot title 

p.name = sprintf(['A13.5 (2010) two-head station #%d, cast #' cast_str],p.ladcp_station);
   
switch stn
   case 12
    p.name = sprintf(['A13.5 (2010) upward-looking station #%d, cast #' cast_str],p.ladcp_station);
end

% which plot(s) to save (see Appendix F in 'howto.pdf' for the list of plots)
% note: ProcFig. 4 will be generated only if CTD data are provided
%       ProcFig. 12 triggers a mistake when used with auxiliary data
%       Add ProcFig. 5, 6 and 10 if an uplooker instrument is used
%       Add ProcFig. 9 for SADCP

p.saveplot = [1:11 13:14];

%p.saveplot = [];

% disable this constraint under most circumstances

ps.smallfac = [1 0];

% increase if a false bottom is detected

%p.btrk_ts = 10; % 10 is already default value

% path to IGRF coefficients

%f.IGRF='/usr/local/lib/IGRF10.cof'; %default is '/usr/local/lib/IGRF10.cof' in loadnav.m

% Specifics to stations

% The part below was added for post-processing (after the cruise).
% It changes the default parameters to those used for the public
% data processed by LDEO group in the past few years. 

