% command line to process SADCP data into a format that LDEO software can use
% Casts 1-29
%source1='/home/science/current_cruise/data/RB1002leg2_reproc/os75nb/contour';
%mkSADCP(source1,'/home/science/current_cruise/data/shipboard_adcp/ldeo_reprocessed_sadcp_leg2.mat')
% Casts 30-91
%source2='/home/science/current_cruise/data/RB1002leg2a/proc/os75nb/contour';
%mkSADCP(source2,'/home/science/current_cruise/data/shipboard_adcp/ldeo_reprocessed_sadcp_leg2a.mat')

% cruise ID and name of person who processes the data %%%%%%%%%%%

p.cruise_id = 'A10_2011';
p.whoami = 'S. Eggleston';

% specify the cast number for stations with several available casts.
% in the case below, station 79 had two casts, and we want to use cast #1 only
%CAST(79) = 1;


% station number %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
p.ladcp_station = stn;

% filename of the raw LADCP data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ladcp_datapath = ['/home/science/' p.cruise_id '/data/ladcp/']
ladcp_filename_start = 'wh'; 
ladcp_filename_end = '.dat';
cast_loc_index = [7 8];
stn_str = sprintf('%03d',stn);

[w,ladcp_list]=unix(['ls ' ladcp_datapath ladcp_filename_start stn_str '*' ladcp_filename_end '*']);

if w ~= 0
  error('error while reading the LADCP up-looker data...')
end

% cases where there are several casts available
%switch stn
%   case 79
%    if CAST(stn) == 1
%     ladcp_list = ladcp_list(1:49); % first cast is taken
%    elseif CAST(stn) == 2
%     ladcp_list = ladcp_list(50:end); % second cast is taken
%    end
%end

ladcp_filename = ladcp_list(1:end-1)

cast_str = ladcp_filename(length(ladcp_datapath)+cast_loc_index);

cast_str_ctd = cast_str;

f.ladcpdo = sprintf(ladcp_filename);
f.ladcpup = '';
   
% CTD time series %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ctd_data = 'y'; % 'y' or 'n'

if ctd_data == 'y'

% If Scripps CTD data are available
ctd_datapath = ['/home/science/' p.cruise_id '/data/ctd_timeseries/'];
ctd_filename_start = '';
ctd_filename_end = '.ctd';

ctd_filename=[ctd_datapath ctd_filename_start stn_str cast_str_ctd ctd_filename_end]

f.ctd = sprintf(ctd_filename);

% number of header lines (before the CTD data start) %%%%%%%%%%%%
f.ctd_header_lines = 0; % file layout

% number of data fields per CTD scan %%%%%%%%%%%%%%%%%%%%%%%%%%%%
f.ctd_fields_per_line = 11;

% field number for pressure, temperature, salinity and time %%%%%

f.ctd_pressure_field = 2;
f.ctd_temperature_field = 3;
f.ctd_salinity_field = 4;
f.ctd_time_field = 1;

% time base to use %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 0=elapsed, 1=year-day, 2=gregorian
f.ctd_time_base = 0;

end

% GPS data? %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
gps_data = 'y'; % 'y' or 'n'

if gps_data == 'y'

% GPS filename %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
f.nav = f.ctd; % if GPS and CTD data are in the same file

% number of header lines (before the GPS data start) %%%%%%%%%%%%
f.nav_header_lines = 0;
 
% number of fields per scan %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
f.nav_fields_per_line = 11;

% field number for time, latitude and longitude %%%%%%%%%%%%%%%%%

f.nav_time_field = 1;
f.nav_lat_field = 10;
f.nav_lon_field = 11;

% time base to use %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 0=elapsed (default), 1=year-day, 2=gregorian
% 0 only if GPS and CTD data are co-recorded
f.nav_time_base = 0;

end

% SADCP data? %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%sadcp_data_from_UH=input('SADCP data?\n','s'); % 'y'=yes, 'n'=no

sadcp_data_from_UH='y'; % 'y' or 'n'

if sadcp_data_from_UH == 'y'

% SADCP MATLAB file %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if stn <= 29

   f.sadcp = '/home/science/current_cruise/data/shipboard_adcp/ldeo_reprocessed_sadcp_leg2.mat';

elseif and(stn>=30,stn<=91)

   f.sadcp = '/home/science/current_cruise/data/shipboard_adcp/ldeo_reprocessed_sadcp_leg2a.mat';

end

p.sadcp_dtok = 0

end

% CTD profile? %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ctdprof = 'n'; % 'y' or 'n'

if ctdprof == 'y'

ctdprof_datapath = ['/home/science/' p.cruise_id '/data/ctd_2db/'];
ctdprof_filename_start = '';
ctdprof_filename_end = '.ctd';

ctdprof_filename=[ctdprof_datapath stn_str cast_str ctdprof_filename_end];

f.ctdprof = sprintf(ctdprof_filename);

end

% magnetic deviation %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if gps_data == 'n' % only if there is no GPS data; if there is,
                   % the magnetic devation will be set using geomag60

p.drot = magdev(latvec(stn+1),lonvec(stn+1)) % magnetic deviation

%or

%  p.poss =  0; % start position
%  p.pose =  0; %   end position

end

% save matlab files? %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

p.savemat = 1; % yes=1, no=0 (default)

% save figures? %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% p.saveplot_png = []; % yes=nothing, no=1 (default)

more off
clear pk

% basename of the checkpoint files %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
f.checkpoints = sprintf('checkpoints/%03d',stn);

% basename of the output files %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
f.res = sprintf('processed/%03d',stn);

% plot title 

p.name = sprintf(['A10 (2011) one-head station #%d, cast #' cast_str],p.ladcp_station);
   
% which plot(s) to save (see Appendix F in 'howto.pdf' for the list of plots)
% note: ProcFig. 4 will be generated only if CTD data are provided
%       ProcFig. 12 triggers a mistake when used with auxiliary data
%       Add ProcFig. 5, 6 and 10 if an uplooker instrument is used
%       Add ProcFig. 9 for SADCP

p.saveplot = [1:11 13:14];

%p.saveplot = [];

% disable this constraint under most circumstances

ps.smallfac = [1 0];

% increase if a false bottom is detected

%p.btrk_ts = 10; % 10 is already default value

% path to IGRF coefficients

%f.IGRF='/usr/local/lib/IGRF10.cof'; %default is '/usr/local/lib/IGRF10.cof' in loadnav.m

% Specifics to stations

