% This is a template for a single-head set up
% Modify it accordingly to your cruise (look for 'TO MODIFY' tags)

% cruise ID and name of person who processes the data %%%%%%%%%%%

p.cruise_id = 'I5S_2009'; % TO MODIFY
p.whoami = 'F. Ascani'; % TO MODIFY

% root
root = '/home/science/';

% station number %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
p.ladcp_station = stn;

% command line to process SADCP data into a format that LDEO software can use
source='/home/science/current_cruise/data/RB1002leg2_reproc/os75nb/contour'; % location of the processed SADCP data % TO MODIFY
dest='/home/science/current_cruise/proc/ladcp_ldeo/data/ldeo_reprocessed_sadcp/ldeo_reprocessed_sadcp.mat'; % destination of the LDEO-formatted MATLAB SADCP data 
mkSADCP(source,dest)

% filename of the raw LADCP data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ladcp_datapath = [root p.cruise_id '/data/ladcp/']
ladcp_filename_start = 'bb'; % TO MODIFY
ladcp_filename_end = '.dat';
cast_loc_index = [7 8];
stn_str = sprintf('%03d',stn);

[w,ladcp_list]=unix(['ls ' ladcp_datapath ladcp_filename_start stn_str '*' ladcp_filename_end]);

if w ~= 0
  error('error while reading the LADCP data...')
end

ladcp_filename = ladcp_list(1:end-1);
if ladcp_filename(1) ~= '/';ladcp_filename = ladcp_filename(2:end);end
cast_str = ladcp_filename(length(ladcp_datapath)+cast_loc_index);

f.ladcpdo = sprintf(ladcp_filename);

% CTD time series %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ctd_data='y' % 'y'=yes, 'n'=no

if ctd_data == 'y'

   ctd_datapath = [root p.cruise_id '/data/ctd_timeseries/'];
   ctd_filename_start = '';
   ctd_filename_end = '.ctd';

   ctd_filename=[ctd_datapath stn_str cast_str ctd_filename_end];

   f.ctd = sprintf(ctd_filename);

   % number of header lines (before the CTD data start) %%%%%%%%%%%%
   f.ctd_header_lines = 0; % file layout

   % number of data fields per CTD scan %%%%%%%%%%%%%%%%%%%%%%%%%%%%
   f.ctd_fields_per_line = 11;

   % field number for pressure, temperature, salinity and time %%%%%
   f.ctd_pressure_field = 2;
   f.ctd_temperature_field = 3;
   f.ctd_salinity_field = 4;
   f.ctd_time_field = 1;

   % time base to use %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   f.ctd_time_base = 0; % 0=elapsed, 1=year-day, 2=gregorian

end

% GPS data? %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
gps_data='y' % 'y'=yes, 'n'=no

if gps_data == 'y'

   % GPS filename %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   f.nav = f.ctd; % if GPS and CTD data are in the same file
   
   % number of header lines (before the GPS data start) %%%%%%%%%%%%
   f.nav_header_lines = 0;
 
   % number of fields per scan %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   f.nav_fields_per_line = 11;

   % field number for time, latitude and longitude %%%%%%%%%%%%%%%%%
   f.nav_time_field = 1;
   f.nav_lat_field = 10;
   f.nav_lon_field = 11;

   % time base to use %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   f.nav_time_base = 0; % 0=elapsed (default), 1=year-day, 2=gregorian
                     % 0 only if GPS and CTD data are co-recorded

end

% SADCP data? %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

sadcp_data_from_UH='y' % 'y'=yes, 'n'=no

if sadcp_data_from_UH == 'y'

   % SADCP MATLAB file %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   f.sadcp = dest;

end

% CTD profile? %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ctdprof = 'y' % 'y'=yes, 'n'=no

if ctdprof == 'y'

   ctdprof_datapath = [root p.cruise_id '/data/ctd_2db/'];
   ctdprof_filename_start = '';
   ctdprof_filename_end = '.ctd';

   ctdprof_filename=[ctdprof_datapath stn_str cast_str ctdprof_filename_end];

   f.ctdprof = sprintf(ctdprof_filename);

end

% save matlab files? %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

p.savemat = 1; % yes=1, no=0 (default)

% save figures? %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

more off
clear pk

% basename of the checkpoint files %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
f.checkpoints = sprintf('checkpoints/%03d',stn);

% basename of the output files %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
f.res = sprintf('processed/%03d',stn);

% plot title
p.name = sprintf('%s cast #%d',p.cruise_id,p.ladcp_station);

% which plot(s) to save (see Appendix F in 'howto.pdf' for the list of plots)
% note: ProcFig. 4 will be generated only if CTD data are provided
%       ProcFig. 12 triggers a mistake when used with auxiliary data
%       Add ProcFig. 5, 6 and 10 if an uplooker instrument is used
%       Add ProcFig. 9 for SADCP

p.saveplot = [1:4 7:8 11 13:14];

% disable this constraint under most circumstances
ps.smallfac = [1 0]; 